#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_PI_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_PI_HPP_INCLUDED

#include <boost/simd/constant/include/constants/pi.hpp>

#endif
